@@ -14,7 +14,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from six.moves.urllib import parse
+from urllib import parse
 
 from troveclient.apiclient import exceptions
 
@@ -28,7 +28,7 @@ def append_query_strings(url, **query_strings):
     if not query_strings:
         return url
     query = '&'.join('{0}={1}'.format(key, val)
-                     for key, val in query_strings.items() if val)
+                     for key, val in query_strings.items() if val is not None)
     return url + ('?' + query if query else "")
 
 
