@@ -14,7 +14,6 @@
 
 from osc_lib.command import command
 from osc_lib import utils
-import six
 
 from troveclient import exceptions
 from troveclient.i18n import _
@@ -58,8 +57,8 @@ class ListDatabaseFlavors(command.Lister):
         db_flavors = self.app.client_manager.database.flavors
         if parsed_args.datastore_type and parsed_args.datastore_version_id:
             flavors = db_flavors.list_datastore_version_associated_flavors(
-                datastore_type=parsed_args.datastore_type,
-                datastore_version_id=parsed_args.datastore_version_id)
+                datastore=parsed_args.datastore_type,
+                version_id=parsed_args.datastore_version_id)
         elif (not parsed_args.datastore_type and not
               parsed_args.datastore_version_id):
             flavors = db_flavors.list()
@@ -94,4 +93,4 @@ class ShowDatabaseFlavor(command.ShowOne):
         flavor = utils.find_resource(db_flavors,
                                      parsed_args.flavor)
         flavor = set_attributes_for_print_detail(flavor)
-        return zip(*sorted(six.iteritems(flavor)))
+        return zip(*sorted(list(flavor.items())))
