@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2011 OpenStack Foundation
 # Copyright 2013 Rackspace Hosting
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
@@ -18,36 +16,32 @@
 #    under the License.
 
 from troveclient import base
-from troveclient.common import check_for_exceptions
+from troveclient import common
 
 
 class Quotas(base.ManagerWithFind):
-    """
-    Manage :class:`Quota` information.
-    """
+    """Manage :class:`Quota` information."""
 
     resource_class = base.Resource
 
     def show(self, tenant_id):
-        """Get a list of all quotas for a tenant id"""
+        """Get a list of all quotas for a tenant id."""
 
         url = "/mgmt/quotas/%s" % tenant_id
         resp, body = self.api.client.get(url)
-        check_for_exceptions(resp, body)
+        common.check_for_exceptions(resp, body, url)
         if not body:
             raise Exception("Call to " + url + " did not return a body.")
         if 'quotas' not in body:
             raise Exception("Missing key value 'quotas' in response body.")
-        return body['quotas']
+        return [self.resource_class(self, quota) for quota in body['quotas']]
 
     def update(self, id, quotas):
-        """
-        Set limits for quotas
-        """
+        """Set limits for quotas."""
         url = "/mgmt/quotas/%s" % id
         body = {"quotas": quotas}
         resp, body = self.api.client.put(url, body=body)
-        check_for_exceptions(resp, body)
+        common.check_for_exceptions(resp, body, url)
         if not body:
             raise Exception("Call to " + url + " did not return a body.")
         if 'quotas' not in body:
